==> swagger-client-3.19.11.jar: META-INF/resources/webjars/swagger-client/3.19.11/lib/resolver/apidom/reference/dereference/strategies/openapi-3-1-swagger-client/visitors/properties.js <==
"use strict";

exports.__esModule = true;
exports.default = void 0;
var _apidomCore = require("@swagger-api/apidom-core");
var _compose = _interopRequireDefault(require("../utils/compose.js"));
var _toPath = _interopRequireDefault(require("../utils/to-path.js"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const ModelPropertyMacroVisitor = (0, _compose.default)({
  init({
    modelPropertyMacro,
    options
  }) {
    this.modelPropertyMacro = modelPropertyMacro;
    this.options = options;
  },
  props: {
    modelPropertyMacro: null,
    options: null,
    SchemaElement: {
      leave(schemaElement, key, parent, path, ancestors) {
        if (typeof schemaElement.properties === 'undefined') return;
        if (!(0, _apidomCore.isObjectElement)(schemaElement.properties)) return;
        schemaElement.properties.forEach(property => {
          if (!(0, _apidomCore.isObjectElement)(property)) return;
          try {
            const macroValue = this.modelPropertyMacro((0, _apidomCore.toValue)(property));
            property.set('default', macroValue);
          } catch (error) {
            var _this$options$derefer, _this$options$derefer2;
            const macroError = new Error(error, {
              cause: error
            });
            macroError.fullPath = [...(0, _toPath.default)([...ancestors, parent, schemaElement]), 'properties'];
            (_this$options$derefer = this.options.dereference.dereferenceOpts) === null || _this$options$derefer === void 0 || (_this$options$derefer = _this$options$derefer.errors) === null || _this$options$derefer === void 0 || (_this$options$derefer2 = _this$options$derefer.push) === null || _this$options$derefer2 === void 0 ? void 0 : _this$options$derefer2.call(_this$options$derefer, macroError);
          }
        });
      }
    }
  }
});
var _default = ModelPropertyMacroVisitor;
exports.default = _default;

==> swagger-client-3.24.5.jar: META-INF/resources/webjars/swagger-client/3.24.5/lib/resolver/apidom/reference/dereference/strategies/openapi-3-1-swagger-client/visitors/properties.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault").default;
exports.__esModule = true;
exports.default = void 0;
var _apidomCore = require("@swagger-api/apidom-core");
var _compose = _interopRequireDefault(require("../utils/compose.js"));
var _toPath = _interopRequireDefault(require("../utils/to-path.js"));
const ModelPropertyMacroVisitor = (0, _compose.default)({
  init(_ref) {
    let {
      modelPropertyMacro,
      options
    } = _ref;
    this.modelPropertyMacro = modelPropertyMacro;
    this.options = options;
  },
  props: {
    modelPropertyMacro: null,
    options: null,
    SchemaElement: {
      leave(schemaElement, key, parent, path, ancestors) {
        if (typeof schemaElement.properties === 'undefined') return;
        if (!(0, _apidomCore.isObjectElement)(schemaElement.properties)) return;
        schemaElement.properties.forEach(property => {
          if (!(0, _apidomCore.isObjectElement)(property)) return;
          try {
            const macroValue = this.modelPropertyMacro((0, _apidomCore.toValue)(property));
            property.set('default', macroValue);
          } catch (error) {
            var _this$options$derefer;
            const macroError = new Error(error, {
              cause: error
            });
            macroError.fullPath = [...(0, _toPath.default)([...ancestors, parent, schemaElement]), 'properties'];
            (_this$options$derefer = this.options.dereference.dereferenceOpts) == null || (_this$options$derefer = _this$options$derefer.errors) == null || _this$options$derefer.push == null || _this$options$derefer.push(macroError);
          }
        });
      }
    }
  }
});
var _default = exports.default = ModelPropertyMacroVisitor;
